nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Rstgsm

Enum Rstgsm 

#[repr(u8)]
pub enum Rstgsm { RSTGSM_0 = 0, RSTGSM_1 = 1, RSTGSM_2 = 2, RSTGSM_3 = 3, }

Variants



RSTGSM_0 = 0

Idle, waiting for the first data pattern write.



RSTGSM_1 = 1

Waiting for the second data pattern write.



RSTGSM_2 = 2

The 2-write sequence has completed. Generate the specified gate reset(s). After the reset is performed, this machine returns to the idle (waiting for first data pattern write) state. The “01” state persists for only one clock cycle. Software cannot observe this state.



RSTGSM_3 = 3

This state encoding is never used and therefore reserved.

Implementations

Source

impl Rstgsm

pub const fn from_bits(val: u8) -> Rstgsm

pub const fn to_bits(self) -> u8